@@ -26,9 +26,11 @@ __all__ = [basename(f)[:-3] for f in modules if isfile(f)
            and not f.endswith('__init__.py')]
 
 try:
+    from .brem import Windows, POSIX
     from .brem import BasicRemoteExecutionManager
     from .brem import RemoteRunControl
     from .brem import RemoteRunControlSignals
+    from .AsyncCopyOverSSH import AsyncCopyOverSSH, RemoteAsyncCopyOverSSHSignals
     
 
 except ImportError:
